<?php

/*
		Généalogik
		
        Class for table : event_source.

        07/03/2021 10:45

        lvardon@laposte.net - 2021
        
        Licence libre

        Usage examples :

        <?php

            include_once("classdir/dbconnect.php);
            include_once("classdir/class_event_source.php);

            // Class instance
            $myevent_source = event_source( $db );

            // Select all reccords :
            $results = $myevent_source->selectAll();
            foreach($results as $row) {
                print_r($row);
            } 

            // Select reccord #12 :
            $id = 12;
            $row = $myevent_source->select($id);
            print_r($row);

        ?>

*/
class _event_source {
      
    public $db;
    public $lasterror="";
    public $lastInsertId=-1;
    public $count = 0;
  
    /*
        Initialise object with dbHanler.
                
    */    
    function __construct( $db ) {
        $this->db = $db;
    }

    /*
        Select one reccord from event_source.
        
        parameters : $id (reccord id).
        return : associative array of reccord.
    */
    function select($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.event_id as 'a.event_id',
			a.source_id as 'a.source_id',
			a.document_id as 'a.document_id',
			a.datecreated as 'a.datecreated',

 			b1.id as 'b1.id', 
 			b1.name as 'b1.name', 
 			b1.description as 'b1.description', 
 			b1.private as 'b1.private', 
 			b1.date_begin as 'b1.date_begin', 
 			b1.date_begin_accurate as 'b1.date_begin_accurate', 
 			b1.notesearch as 'b1.notesearch', 
 			b1.datecreated as 'b1.datecreated', 
 			b1.person_1_id as 'b1.person_1_id', 
 			b1.person_2_id as 'b1.person_2_id', 
 			b1.person_3_id as 'b1.person_3_id', 
 			b1.eventtype_id as 'b1.eventtype_id', 
 			b1.place_id as 'b1.place_id', 
 			c2.id as 'c2.id', 
 			c2.name as 'c2.name', 
 			c2.description as 'c2.description', 
 			c2.private as 'c2.private', 
 			c2.category as 'c2.category', 
 			c2.icon as 'c2.icon', 
 			c2.sourcetext as 'c2.sourcetext', 
 			c2.sourceurl as 'c2.sourceurl', 
 			c2.quality as 'c2.quality', 
 			c2.page as 'c2.page', 
 			c2.citation as 'c2.citation', 
 			c2.textdraduction as 'c2.textdraduction', 
 			c2.notesearch as 'c2.notesearch', 
 			c2.datecreated as 'c2.datecreated', 
 			d3.id as 'd3.id', 
 			d3.name as 'd3.name', 
 			d3.description as 'd3.description', 
 			d3.private as 'd3.private', 
 			d3.icon as 'd3.icon', 
 			d3.url as 'd3.url', 
 			d3.cote as 'd3.cote', 
 			d3.notesearch as 'd3.notesearch', 
 			d3.datecreated as 'd3.datecreated', 
 			d3.depot_id as 'd3.depot_id', 
 			d3.documenttype_id as 'd3.documenttype_id' 

		from event_source a 
 			left outer join document d3 on d3.id =  a.document_id 
 			left outer join source c2 on c2.id =  a.source_id 
 			left outer join event b1 on b1.id =  a.event_id 

		where a.id = :id; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    function selectPrev($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.event_id as 'a.event_id',
			a.source_id as 'a.source_id',
			a.document_id as 'a.document_id',
			a.datecreated as 'a.datecreated',

 			b1.id as 'b1.id', 
 			b1.name as 'b1.name', 
 			b1.description as 'b1.description', 
 			b1.private as 'b1.private', 
 			b1.date_begin as 'b1.date_begin', 
 			b1.date_begin_accurate as 'b1.date_begin_accurate', 
 			b1.notesearch as 'b1.notesearch', 
 			b1.datecreated as 'b1.datecreated', 
 			b1.person_1_id as 'b1.person_1_id', 
 			b1.person_2_id as 'b1.person_2_id', 
 			b1.person_3_id as 'b1.person_3_id', 
 			b1.eventtype_id as 'b1.eventtype_id', 
 			b1.place_id as 'b1.place_id', 
 			c2.id as 'c2.id', 
 			c2.name as 'c2.name', 
 			c2.description as 'c2.description', 
 			c2.private as 'c2.private', 
 			c2.category as 'c2.category', 
 			c2.icon as 'c2.icon', 
 			c2.sourcetext as 'c2.sourcetext', 
 			c2.sourceurl as 'c2.sourceurl', 
 			c2.quality as 'c2.quality', 
 			c2.page as 'c2.page', 
 			c2.citation as 'c2.citation', 
 			c2.textdraduction as 'c2.textdraduction', 
 			c2.notesearch as 'c2.notesearch', 
 			c2.datecreated as 'c2.datecreated', 
 			d3.id as 'd3.id', 
 			d3.name as 'd3.name', 
 			d3.description as 'd3.description', 
 			d3.private as 'd3.private', 
 			d3.icon as 'd3.icon', 
 			d3.url as 'd3.url', 
 			d3.cote as 'd3.cote', 
 			d3.notesearch as 'd3.notesearch', 
 			d3.datecreated as 'd3.datecreated', 
 			d3.depot_id as 'd3.depot_id', 
 			d3.documenttype_id as 'd3.documenttype_id' 

		from event_source a 
 			left outer join document d3 on d3.id =  a.document_id 
 			left outer join source c2 on c2.id =  a.source_id 
 			left outer join event b1 on b1.id =  a.event_id 

		where a.id =  (SELECT id FROM event_source WHERE id < :id ORDER BY id DESC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }


    function selectNext($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.event_id as 'a.event_id',
			a.source_id as 'a.source_id',
			a.document_id as 'a.document_id',
			a.datecreated as 'a.datecreated',

 			b1.id as 'b1.id', 
 			b1.name as 'b1.name', 
 			b1.description as 'b1.description', 
 			b1.private as 'b1.private', 
 			b1.date_begin as 'b1.date_begin', 
 			b1.date_begin_accurate as 'b1.date_begin_accurate', 
 			b1.notesearch as 'b1.notesearch', 
 			b1.datecreated as 'b1.datecreated', 
 			b1.person_1_id as 'b1.person_1_id', 
 			b1.person_2_id as 'b1.person_2_id', 
 			b1.person_3_id as 'b1.person_3_id', 
 			b1.eventtype_id as 'b1.eventtype_id', 
 			b1.place_id as 'b1.place_id', 
 			c2.id as 'c2.id', 
 			c2.name as 'c2.name', 
 			c2.description as 'c2.description', 
 			c2.private as 'c2.private', 
 			c2.category as 'c2.category', 
 			c2.icon as 'c2.icon', 
 			c2.sourcetext as 'c2.sourcetext', 
 			c2.sourceurl as 'c2.sourceurl', 
 			c2.quality as 'c2.quality', 
 			c2.page as 'c2.page', 
 			c2.citation as 'c2.citation', 
 			c2.textdraduction as 'c2.textdraduction', 
 			c2.notesearch as 'c2.notesearch', 
 			c2.datecreated as 'c2.datecreated', 
 			d3.id as 'd3.id', 
 			d3.name as 'd3.name', 
 			d3.description as 'd3.description', 
 			d3.private as 'd3.private', 
 			d3.icon as 'd3.icon', 
 			d3.url as 'd3.url', 
 			d3.cote as 'd3.cote', 
 			d3.notesearch as 'd3.notesearch', 
 			d3.datecreated as 'd3.datecreated', 
 			d3.depot_id as 'd3.depot_id', 
 			d3.documenttype_id as 'd3.documenttype_id' 

		from event_source a 
 			left outer join document d3 on d3.id =  a.document_id 
 			left outer join source c2 on c2.id =  a.source_id 
 			left outer join event b1 on b1.id =  a.event_id 

		where a.id =  (SELECT id FROM event_source WHERE id > :id ORDER BY id ASC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    /*
        Select all reccords from event_source  (with default order).
        
        parameters : None
        return : associative array of reccords.
    */
    function selectAll() {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.event_id as 'a.event_id',
			a.source_id as 'a.source_id',
			a.document_id as 'a.document_id',
			a.datecreated as 'a.datecreated',

 			b1.id as 'b1.id',
 			b1.name as 'b1.name',
 			b1.description as 'b1.description',
 			b1.private as 'b1.private',
 			b1.date_begin as 'b1.date_begin',
 			b1.date_begin_accurate as 'b1.date_begin_accurate',
 			b1.notesearch as 'b1.notesearch',
 			b1.datecreated as 'b1.datecreated',
 			b1.person_1_id as 'b1.person_1_id',
 			b1.person_2_id as 'b1.person_2_id',
 			b1.person_3_id as 'b1.person_3_id',
 			b1.eventtype_id as 'b1.eventtype_id',
 			b1.place_id as 'b1.place_id',
 			c2.id as 'c2.id',
 			c2.name as 'c2.name',
 			c2.description as 'c2.description',
 			c2.private as 'c2.private',
 			c2.category as 'c2.category',
 			c2.icon as 'c2.icon',
 			c2.sourcetext as 'c2.sourcetext',
 			c2.sourceurl as 'c2.sourceurl',
 			c2.quality as 'c2.quality',
 			c2.page as 'c2.page',
 			c2.citation as 'c2.citation',
 			c2.textdraduction as 'c2.textdraduction',
 			c2.notesearch as 'c2.notesearch',
 			c2.datecreated as 'c2.datecreated',
 			d3.id as 'd3.id',
 			d3.name as 'd3.name',
 			d3.description as 'd3.description',
 			d3.private as 'd3.private',
 			d3.icon as 'd3.icon',
 			d3.url as 'd3.url',
 			d3.cote as 'd3.cote',
 			d3.notesearch as 'd3.notesearch',
 			d3.datecreated as 'd3.datecreated',
 			d3.depot_id as 'd3.depot_id',
 			d3.documenttype_id as 'd3.documenttype_id'

		from event_source a 
 			left outer join document d3 on d3.id =  a.document_id 
 			left outer join source c2 on c2.id =  a.source_id 
 			left outer join event b1 on b1.id =  a.event_id 

		;    
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

    /*
        Update event_source 
        
        parameters : $id (reccord id) and fields list values.
        return : True if no error.
    */
    function update( $id, $event_id,$source_id,$document_id,$datecreated ) {

        $this->lasterror="";        

		if ($event_id == '') $event_id = null;
		if ($source_id == '') $source_id = null;
		if ($document_id == '') $document_id = null;
		if ($datecreated == '') $datecreated = null;
		

        if ($this->checkValue( array( 
		$event_id => '',
		$source_id => '',
		$document_id => '',
		$datecreated => ''

) ) == false )
        {
            $this->lasterror="Check fields false";        
            return false;
        }

        $sqlSt="
		update event_source set
			event_id = :event_id,
			source_id = :source_id,
			document_id = :document_id,
			datecreated = :datecreated

		where id = :id; 
            ";

        try {        
            
            $stmt = $this->db->prepare($sqlSt);
            
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);

			$stmt->bindParam(':event_id', $event_id, PDO::PARAM_INT); 
			$stmt->bindParam(':source_id', $source_id, PDO::PARAM_INT); 
			$stmt->bindParam(':document_id', $document_id, PDO::PARAM_INT); 
			$stmt->bindParam(':datecreated', $datecreated, PDO::PARAM_STR); 
 
            $stmt->execute();             
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql update '.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>event_id</b> = [$event_id],<b>source_id</b> = [$source_id],<b>document_id</b> = [$document_id],<b>datecreated</b> = [$datecreated]";
				
				return false;
			}   
			         
            return true;

        } catch (Exception $e) {            
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>event_id</b> = [$event_id],<b>source_id</b> = [$source_id],<b>document_id</b> = [$document_id],<b>datecreated</b> = [$datecreated]";  
            return false;
        }

    }

    /*
        Insert new reccord into event_source.
        
        Parameters : fields values list.
        return : True if no error.
    */
    function insert( $event_id,$source_id,$document_id,$datecreated ) {

        $this->lasterror="";
        $this->lastInsertId = -1;

		if ($event_id == '') $event_id = null;
		if ($source_id == '') $source_id = null;
		if ($document_id == '') $document_id = null;
		if ($datecreated == '') $datecreated = null;
		
		
        if ($this->checkValue( array( 
		$event_id => '',
		$source_id => '',
		$document_id => '',
		$datecreated => ''

) ) == false )
        {
            $this->lasterror="Check fields error";        
            return false;
        }

        $sqlSt="
		insert into event_source (
		event_id,
		source_id,
		document_id,
		datecreated
 
			)
		values (
		:event_id, 
		:source_id, 
		:document_id, 
		:datecreated 
 
			);    
            ";

        try {        

            $stmt = $this->db->prepare($sqlSt);               
			
			$stmt->bindParam(':event_id', $event_id, PDO::PARAM_INT); 
			$stmt->bindParam(':source_id', $source_id, PDO::PARAM_INT); 
			$stmt->bindParam(':document_id', $document_id, PDO::PARAM_INT); 
			$stmt->bindParam(':datecreated', $datecreated, PDO::PARAM_STR); 
 

            $stmt->execute();     
            $this->lastInsertId = $this->db->lastInsertId(); 
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql insert'.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>event_id</b> = [$event_id],<b>source_id</b> = [$source_id],<b>document_id</b> = [$document_id],<b>datecreated</b> = [$datecreated]";
				return false;
			}              
                   
            return true;

        } catch (Exception $e) {
             $this->lasterror = $e->getMessage().'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>event_id</b> = [$event_id],<b>source_id</b> = [$source_id],<b>document_id</b> = [$document_id],<b>datecreated</b> = [$datecreated]";
            return false;
        }
    }

    /*
        Delete one reccord from event_source.
        
        parameters : $id (reccord id).
        return : True if no error.
    */
    function delete($id) {

        $this->lasterror="";

        $sqlSt="
		delete from event_source             
		where id = :id; 
            ";   
     
        try {        

            $stmt = $this->db->prepare($sqlSt);  
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();        
            
			if ($stmt->rowCount() == 0) {
				$this->lasterror = "Erreur Sql delete ".' (<b>Id</b> ='.$id.')';       
				return false;
			}              

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b>='.$id.')';
            return false;
        }
        return true;
    }

    /*
        Get id min, id max, record count from event_source  
        
        parameters : None
        return : count value or False in case of error
    */
	function getCount() {
		
        $this->lasterror="";

        $sqlSt="
		select min(id) as minid, max(id) as maxid, count(*) as count 
		from event_source 
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC); 
            return $results[0];          

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            return array( 'minid' => -1, 'maxid' => -1, 'count' => -1);
        }
        		
		//return $this->count;
		return $results[0];
	}




	public $colmeta = [
	'a.id' => array (
		'metades' => "",
		'sortformat' => "{{sortformat}}",
		'listlen' => 4,
		'listlib' => 'a_id',
		'listlink' => 'on',
		'selectlen' => 4,
		'selectlib' => 'a_id',
		'selectlink' => '',
		'selectdisplay' => '',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => '', 
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 

		),
	'a.event_id' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 4,
		'listlib' => 'a_event_id' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'a_event_id' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.source_id' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 4,
		'listlib' => 'a_source_id' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'a_source_id' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.document_id' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 4,
		'listlib' => 'a_document_id' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'a_document_id' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.datecreated' => array ( 
		'metades' => "",
		'sortformat' => "date", 
		'listlen' => 4,
		'listlib' => 'a_datecreated' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'a_datecreated' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),

 	'b1.id' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.name' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'name', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'name', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.description' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'description', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'description', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.private' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'private', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'private', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.date_begin' => array (  // Event
		'metades' => "",
		'sortformat' => "date",
		'listlen' => 0,
		'listlib' => 'date_begin', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'date_begin', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.date_begin_accurate' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'date_begin_accurate', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'date_begin_accurate', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.notesearch' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'notesearch', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'notesearch', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.datecreated' => array (  // Event
		'metades' => "",
		'sortformat' => "date",
		'listlen' => 0,
		'listlib' => 'datecreated', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'datecreated', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.person_1_id' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'person_1_id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'person_1_id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.person_2_id' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'person_2_id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'person_2_id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.person_3_id' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'person_3_id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'person_3_id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.eventtype_id' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'eventtype_id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'eventtype_id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'b1.place_id' => array (  // Event
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'place_id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'place_id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.id' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.name' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'name', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'name', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.description' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'description', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'description', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.private' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'private', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'private', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.category' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'category', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'category', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.icon' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'icon', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'icon', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.sourcetext' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'sourcetext', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'sourcetext', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.sourceurl' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 8,
		'listlib' => 'sourceurl', 
		'listlink' => '' ,
		'selectlen' => 8,
		'selectlib' => 'sourceurl', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.quality' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'quality', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'quality', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.page' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'page', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'page', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.citation' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'citation', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'citation', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.textdraduction' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'textdraduction', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'textdraduction', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.notesearch' => array (  // Source
		'metades' => "",
		'sortformat' => "",
		'listlen' => 8,
		'listlib' => 'notesearch', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'notesearch', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'c2.datecreated' => array (  // Source
		'metades' => "",
		'sortformat' => "date",
		'listlen' => 0,
		'listlib' => 'datecreated', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'datecreated', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.id' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.name' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'name', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'name', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.description' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'description', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'description', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.private' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'private', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'private', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.icon' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'icon', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'icon', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.url' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'url', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'url', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.cote' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'cote', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'cote', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.notesearch' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'notesearch', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'notesearch', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.datecreated' => array (  // Document
		'metades' => "",
		'sortformat' => "date",
		'listlen' => 0,
		'listlib' => 'datecreated', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'datecreated', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.depot_id' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'depot_id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'depot_id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
), 
 	'd3.documenttype_id' => array (  // Document
		'metades' => "",
		'sortformat' => "",
		'listlen' => 0,
		'listlib' => 'documenttype_id', 
		'listlink' => '' ,
		'selectlen' => 0,
		'selectlib' => 'documenttype_id', 
		'selectlink' => '{{fkselectlink}}',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
) 
			
	];

    /*
        Get field property value
        
        Parameters : field name and property name.
        return : value of property.
    */

	function getMeta( $fieldkey , $metakey ) {
		return $this->colmeta [$fieldkey][$metakey];
	}

    /*
        Get labels for list table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderList() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['listlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['listlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenList( $field ) {		
		
		return $this->colmeta[$field]['listlen'];
	}

	function getTableFieldLinkList( $field ) {		
		
		return $this->colmeta[$field]['listlink'];
	}

    /*
        Get labels for select table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderSelect() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['selectlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['selectlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlen'];
	}

	function getTableFieldLinkSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlink'];
	}

	
    /*
        Check user input values for event_source.
        
        Parameters : array of fields with regexp  paterns. ex: array( $nom =>'^(?!\s*$).+' , $icone => '')
        return : False if at last one regexp does not match.
    */
    function checkValue( $arrayCheck ) {

        $indexfield=1;
        foreach ( $arrayCheck as $value => $pattern) {

            if ($pattern=='') continue;

            $pattern='/'.$pattern.'/';

            if (!preg_match($pattern, $value)) {
                $this->lasterror = "Erreur champ #".$indexfield. '. Valeur:['.$value.']';
                return false;                
            }

            $indexfield+=1;

        }

        return true;
    }

} // end class

?>
