<?php

/*
		Généalogik
		
        Class for table : metadata.

        07/03/2021 10:45

        lvardon@laposte.net - 2021
        
        Licence libre

        Usage examples :

        <?php

            include_once("classdir/dbconnect.php);
            include_once("classdir/class_metadata.php);

            // Class instance
            $mymetadata = metadata( $db );

            // Select all reccords :
            $results = $mymetadata->selectAll();
            foreach($results as $row) {
                print_r($row);
            } 

            // Select reccord #12 :
            $id = 12;
            $row = $mymetadata->select($id);
            print_r($row);

        ?>

*/
class _metadata {
      
    public $db;
    public $lasterror="";
    public $lastInsertId=-1;
    public $count = 0;
  
    /*
        Initialise object with dbHanler.
                
    */    
    function __construct( $db ) {
        $this->db = $db;
    }

    /*
        Select one reccord from metadata.
        
        parameters : $id (reccord id).
        return : associative array of reccord.
    */
    function select($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.code as 'a.code',
			a.value as 'a.value',
			a.type as 'a.type',
			a.description as 'a.description'


		from metadata a 

		where a.id = :id; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    function selectPrev($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.code as 'a.code',
			a.value as 'a.value',
			a.type as 'a.type',
			a.description as 'a.description'


		from metadata a 

		where a.id =  (SELECT id FROM metadata WHERE id < :id ORDER BY id DESC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }


    function selectNext($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.code as 'a.code',
			a.value as 'a.value',
			a.type as 'a.type',
			a.description as 'a.description'


		from metadata a 

		where a.id =  (SELECT id FROM metadata WHERE id > :id ORDER BY id ASC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    /*
        Select all reccords from metadata  (with default order).
        
        parameters : None
        return : associative array of reccords.
    */
    function selectAll() {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.code as 'a.code',
			a.value as 'a.value',
			a.type as 'a.type',
			a.description as 'a.description'


		from metadata a 

		;    
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

    /*
        Update metadata 
        
        parameters : $id (reccord id) and fields list values.
        return : True if no error.
    */
    function update( $id, $name,$code,$value,$type,$description ) {

        $this->lasterror="";        

		if ($name == '') $name = null;
		if ($code == '') $code = null;
		if ($value == '') $value = null;
		if ($type == '') $type = null;
		if ($description == '') $description = null;
		

        if ($this->checkValue( array( 
		$name => '',
		$code => '',
		$value => '',
		$type => '',
		$description => ''

) ) == false )
        {
            $this->lasterror="Check fields false";        
            return false;
        }

        $sqlSt="
		update metadata set
			name = :name,
			code = :code,
			value = :value,
			type = :type,
			description = :description

		where id = :id; 
            ";

        try {        
            
            $stmt = $this->db->prepare($sqlSt);
            
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);

			$stmt->bindParam(':name', $name, PDO::PARAM_STR); 
			$stmt->bindParam(':code', $code, PDO::PARAM_STR); 
			$stmt->bindParam(':value', $value, PDO::PARAM_STR); 
			$stmt->bindParam(':type', $type, PDO::PARAM_STR); 
			$stmt->bindParam(':description', $description, PDO::PARAM_STR); 
 
            $stmt->execute();             
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql update '.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>code</b> = [$code],<b>value</b> = [$value],<b>type</b> = [$type],<b>description</b> = [$description]";
				
				return false;
			}   
			         
            return true;

        } catch (Exception $e) {            
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>code</b> = [$code],<b>value</b> = [$value],<b>type</b> = [$type],<b>description</b> = [$description]";  
            return false;
        }

    }

    /*
        Insert new reccord into metadata.
        
        Parameters : fields values list.
        return : True if no error.
    */
    function insert( $name,$code,$value,$type,$description ) {

        $this->lasterror="";
        $this->lastInsertId = -1;

		if ($name == '') $name = null;
		if ($code == '') $code = null;
		if ($value == '') $value = null;
		if ($type == '') $type = null;
		if ($description == '') $description = null;
		
		
        if ($this->checkValue( array( 
		$name => '',
		$code => '',
		$value => '',
		$type => '',
		$description => ''

) ) == false )
        {
            $this->lasterror="Check fields error";        
            return false;
        }

        $sqlSt="
		insert into metadata (
		name,
		code,
		value,
		type,
		description
 
			)
		values (
		:name, 
		:code, 
		:value, 
		:type, 
		:description 
 
			);    
            ";

        try {        

            $stmt = $this->db->prepare($sqlSt);               
			
			$stmt->bindParam(':name', $name, PDO::PARAM_STR); 
			$stmt->bindParam(':code', $code, PDO::PARAM_STR); 
			$stmt->bindParam(':value', $value, PDO::PARAM_STR); 
			$stmt->bindParam(':type', $type, PDO::PARAM_STR); 
			$stmt->bindParam(':description', $description, PDO::PARAM_STR); 
 

            $stmt->execute();     
            $this->lastInsertId = $this->db->lastInsertId(); 
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql insert'.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>code</b> = [$code],<b>value</b> = [$value],<b>type</b> = [$type],<b>description</b> = [$description]";
				return false;
			}              
                   
            return true;

        } catch (Exception $e) {
             $this->lasterror = $e->getMessage().'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>code</b> = [$code],<b>value</b> = [$value],<b>type</b> = [$type],<b>description</b> = [$description]";
            return false;
        }
    }

    /*
        Delete one reccord from metadata.
        
        parameters : $id (reccord id).
        return : True if no error.
    */
    function delete($id) {

        $this->lasterror="";

        $sqlSt="
		delete from metadata             
		where id = :id; 
            ";   
     
        try {        

            $stmt = $this->db->prepare($sqlSt);  
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();        
            
			if ($stmt->rowCount() == 0) {
				$this->lasterror = "Erreur Sql delete ".' (<b>Id</b> ='.$id.')';       
				return false;
			}              

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b>='.$id.')';
            return false;
        }
        return true;
    }

    /*
        Get id min, id max, record count from metadata  
        
        parameters : None
        return : count value or False in case of error
    */
	function getCount() {
		
        $this->lasterror="";

        $sqlSt="
		select min(id) as minid, max(id) as maxid, count(*) as count 
		from metadata 
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC); 
            return $results[0];          

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            return array( 'minid' => -1, 'maxid' => -1, 'count' => -1);
        }
        		
		//return $this->count;
		return $results[0];
	}




	public $colmeta = [
	'a.id' => array (
		'metades' => "Identifiant paramètre",
		'sortformat' => "{{sortformat}}",
		'listlen' => 4,
		'listlib' => 'id',
		'listlink' => 'on',
		'selectlen' => 4,
		'selectlib' => 'id',
		'selectlink' => '',
		'selectdisplay' => '',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => '', 
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 

		),
	'a.name' => array ( 
		'metades' => "name",
		'sortformat' => "", 
		'listlen' => 24,
		'listlib' => 'name' , 
		'listlink' => '',
		'selectlen' => 24,
		'selectlib' => 'name' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.code' => array ( 
		'metades' => "code",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'code' , 
		'listlink' => '',
		'selectlen' => 12,
		'selectlib' => 'code' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.value' => array ( 
		'metades' => "value",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'value' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'value' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.type' => array ( 
		'metades' => "type",
		'sortformat' => "", 
		'listlen' => 6,
		'listlib' => 'type' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'type' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.description' => array ( 
		'metades' => "description",
		'sortformat' => "", 
		'listlen' => 4,
		'listlib' => 'description' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'description' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
)

			
	];

    /*
        Get field property value
        
        Parameters : field name and property name.
        return : value of property.
    */

	function getMeta( $fieldkey , $metakey ) {
		return $this->colmeta [$fieldkey][$metakey];
	}

    /*
        Get labels for list table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderList() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['listlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['listlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenList( $field ) {		
		
		return $this->colmeta[$field]['listlen'];
	}

	function getTableFieldLinkList( $field ) {		
		
		return $this->colmeta[$field]['listlink'];
	}

    /*
        Get labels for select table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderSelect() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['selectlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['selectlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlen'];
	}

	function getTableFieldLinkSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlink'];
	}

	
    /*
        Check user input values for metadata.
        
        Parameters : array of fields with regexp  paterns. ex: array( $nom =>'^(?!\s*$).+' , $icone => '')
        return : False if at last one regexp does not match.
    */
    function checkValue( $arrayCheck ) {

        $indexfield=1;
        foreach ( $arrayCheck as $value => $pattern) {

            if ($pattern=='') continue;

            $pattern='/'.$pattern.'/';

            if (!preg_match($pattern, $value)) {
                $this->lasterror = "Erreur champ #".$indexfield. '. Valeur:['.$value.']';
                return false;                
            }

            $indexfield+=1;

        }

        return true;
    }

} // end class

?>
