<?php

/*
		Généalogik
		
        Class for table : source.

        07/03/2021 10:45

        lvardon@laposte.net - 2021
        
        Licence libre

        Usage examples :

        <?php

            include_once("classdir/dbconnect.php);
            include_once("classdir/class_source.php);

            // Class instance
            $mysource = source( $db );

            // Select all reccords :
            $results = $mysource->selectAll();
            foreach($results as $row) {
                print_r($row);
            } 

            // Select reccord #12 :
            $id = 12;
            $row = $mysource->select($id);
            print_r($row);

        ?>

*/
class _source {
      
    public $db;
    public $lasterror="";
    public $lastInsertId=-1;
    public $count = 0;
  
    /*
        Initialise object with dbHanler.
                
    */    
    function __construct( $db ) {
        $this->db = $db;
    }

    /*
        Select one reccord from source.
        
        parameters : $id (reccord id).
        return : associative array of reccord.
    */
    function select($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.description as 'a.description',
			a.private as 'a.private',
			a.category as 'a.category',
			a.icon as 'a.icon',
			a.sourcetext as 'a.sourcetext',
			a.sourceurl as 'a.sourceurl',
			a.quality as 'a.quality',
			a.page as 'a.page',
			a.citation as 'a.citation',
			a.textdraduction as 'a.textdraduction',
			a.notesearch as 'a.notesearch',
			a.datecreated as 'a.datecreated'


		from source a 

		where a.id = :id; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    function selectPrev($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.description as 'a.description',
			a.private as 'a.private',
			a.category as 'a.category',
			a.icon as 'a.icon',
			a.sourcetext as 'a.sourcetext',
			a.sourceurl as 'a.sourceurl',
			a.quality as 'a.quality',
			a.page as 'a.page',
			a.citation as 'a.citation',
			a.textdraduction as 'a.textdraduction',
			a.notesearch as 'a.notesearch',
			a.datecreated as 'a.datecreated'


		from source a 

		where a.id =  (SELECT id FROM source WHERE id < :id ORDER BY id DESC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }


    function selectNext($id) {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.description as 'a.description',
			a.private as 'a.private',
			a.category as 'a.category',
			a.icon as 'a.icon',
			a.sourcetext as 'a.sourcetext',
			a.sourceurl as 'a.sourceurl',
			a.quality as 'a.quality',
			a.page as 'a.page',
			a.citation as 'a.citation',
			a.textdraduction as 'a.textdraduction',
			a.notesearch as 'a.notesearch',
			a.datecreated as 'a.datecreated'


		from source a 

		where a.id =  (SELECT id FROM source WHERE id > :id ORDER BY id ASC LIMIT 1) ; 
			";

        try {        		

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$idkeyname.')';
            return false;
        }
    }

    /*
        Select all reccords from source  (with default order).
        
        parameters : None
        return : associative array of reccords.
    */
    function selectAll() {

        $this->lasterror="";

        $sqlSt="
		select       
			a.id as 'a.id',  
			a.name as 'a.name',
			a.description as 'a.description',
			a.private as 'a.private',
			a.category as 'a.category',
			a.icon as 'a.icon',
			a.sourcetext as 'a.sourcetext',
			a.sourceurl as 'a.sourceurl',
			a.quality as 'a.quality',
			a.page as 'a.page',
			a.citation as 'a.citation',
			a.textdraduction as 'a.textdraduction',
			a.notesearch as 'a.notesearch',
			a.datecreated as 'a.datecreated'


		from source a 

		;    
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC);           
            return $results;

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            $this->count = 0;
            return false;
        }
    }

    /*
        Update source 
        
        parameters : $id (reccord id) and fields list values.
        return : True if no error.
    */
    function update( $id, $name,$description,$private,$category,$icon,$sourcetext,$sourceurl,$quality,$page,$citation,$textdraduction,$notesearch,$datecreated ) {

        $this->lasterror="";        

		if ($name == '') $name = null;
		if ($description == '') $description = null;
		if ($private == '') $private = null;
		if ($category == '') $category = null;
		if ($icon == '') $icon = null;
		if ($sourcetext == '') $sourcetext = null;
		if ($sourceurl == '') $sourceurl = null;
		if ($quality == '') $quality = null;
		if ($page == '') $page = null;
		if ($citation == '') $citation = null;
		if ($textdraduction == '') $textdraduction = null;
		if ($notesearch == '') $notesearch = null;
		if ($datecreated == '') $datecreated = null;
		

        if ($this->checkValue( array( 
		$name => '',
		$description => '',
		$private => '',
		$category => '',
		$icon => '',
		$sourcetext => '',
		$sourceurl => '',
		$quality => '',
		$page => '',
		$citation => '',
		$textdraduction => '',
		$notesearch => '',
		$datecreated => ''

) ) == false )
        {
            $this->lasterror="Check fields false";        
            return false;
        }

        $sqlSt="
		update source set
			name = :name,
			description = :description,
			private = :private,
			category = :category,
			icon = :icon,
			sourcetext = :sourcetext,
			sourceurl = :sourceurl,
			quality = :quality,
			page = :page,
			citation = :citation,
			textdraduction = :textdraduction,
			notesearch = :notesearch,
			datecreated = :datecreated

		where id = :id; 
            ";

        try {        
            
            $stmt = $this->db->prepare($sqlSt);
            
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);

			$stmt->bindParam(':name', $name, PDO::PARAM_STR); 
			$stmt->bindParam(':description', $description, PDO::PARAM_STR); 
			$stmt->bindParam(':private', $private, PDO::PARAM_INT); 
			$stmt->bindParam(':category', $category, PDO::PARAM_STR); 
			$stmt->bindParam(':icon', $icon, PDO::PARAM_STR); 
			$stmt->bindParam(':sourcetext', $sourcetext, PDO::PARAM_STR); 
			$stmt->bindParam(':sourceurl', $sourceurl, PDO::PARAM_STR); 
			$stmt->bindParam(':quality', $quality, PDO::PARAM_INT); 
			$stmt->bindParam(':page', $page, PDO::PARAM_STR); 
			$stmt->bindParam(':citation', $citation, PDO::PARAM_STR); 
			$stmt->bindParam(':textdraduction', $textdraduction, PDO::PARAM_STR); 
			$stmt->bindParam(':notesearch', $notesearch, PDO::PARAM_STR); 
			$stmt->bindParam(':datecreated', $datecreated, PDO::PARAM_STR); 
 
            $stmt->execute();             
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql update '.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>description</b> = [$description],<b>private</b> = [$private],<b>category</b> = [$category],<b>icon</b> = [$icon],<b>sourcetext</b> = [$sourcetext],<b>sourceurl</b> = [$sourceurl],<b>quality</b> = [$quality],<b>page</b> = [$page],<b>citation</b> = [$citation],<b>textdraduction</b> = [$textdraduction],<b>notesearch</b> = [$notesearch],<b>datecreated</b> = [$datecreated]";
				
				return false;
			}   
			         
            return true;

        } catch (Exception $e) {            
            $this->lasterror = $e->getMessage().' (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>description</b> = [$description],<b>private</b> = [$private],<b>category</b> = [$category],<b>icon</b> = [$icon],<b>sourcetext</b> = [$sourcetext],<b>sourceurl</b> = [$sourceurl],<b>quality</b> = [$quality],<b>page</b> = [$page],<b>citation</b> = [$citation],<b>textdraduction</b> = [$textdraduction],<b>notesearch</b> = [$notesearch],<b>datecreated</b> = [$datecreated]";  
            return false;
        }

    }

    /*
        Insert new reccord into source.
        
        Parameters : fields values list.
        return : True if no error.
    */
    function insert( $name,$description,$private,$category,$icon,$sourcetext,$sourceurl,$quality,$page,$citation,$textdraduction,$notesearch,$datecreated ) {

        $this->lasterror="";
        $this->lastInsertId = -1;

		if ($name == '') $name = null;
		if ($description == '') $description = null;
		if ($private == '') $private = null;
		if ($category == '') $category = null;
		if ($icon == '') $icon = null;
		if ($sourcetext == '') $sourcetext = null;
		if ($sourceurl == '') $sourceurl = null;
		if ($quality == '') $quality = null;
		if ($page == '') $page = null;
		if ($citation == '') $citation = null;
		if ($textdraduction == '') $textdraduction = null;
		if ($notesearch == '') $notesearch = null;
		if ($datecreated == '') $datecreated = null;
		
		
        if ($this->checkValue( array( 
		$name => '',
		$description => '',
		$private => '',
		$category => '',
		$icon => '',
		$sourcetext => '',
		$sourceurl => '',
		$quality => '',
		$page => '',
		$citation => '',
		$textdraduction => '',
		$notesearch => '',
		$datecreated => ''

) ) == false )
        {
            $this->lasterror="Check fields error";        
            return false;
        }

        $sqlSt="
		insert into source (
		name,
		description,
		private,
		category,
		icon,
		sourcetext,
		sourceurl,
		quality,
		page,
		citation,
		textdraduction,
		notesearch,
		datecreated
 
			)
		values (
		:name, 
		:description, 
		:private, 
		:category, 
		:icon, 
		:sourcetext, 
		:sourceurl, 
		:quality, 
		:page, 
		:citation, 
		:textdraduction, 
		:notesearch, 
		:datecreated 
 
			);    
            ";

        try {        

            $stmt = $this->db->prepare($sqlSt);               
			
			$stmt->bindParam(':name', $name, PDO::PARAM_STR); 
			$stmt->bindParam(':description', $description, PDO::PARAM_STR); 
			$stmt->bindParam(':private', $private, PDO::PARAM_INT); 
			$stmt->bindParam(':category', $category, PDO::PARAM_STR); 
			$stmt->bindParam(':icon', $icon, PDO::PARAM_STR); 
			$stmt->bindParam(':sourcetext', $sourcetext, PDO::PARAM_STR); 
			$stmt->bindParam(':sourceurl', $sourceurl, PDO::PARAM_STR); 
			$stmt->bindParam(':quality', $quality, PDO::PARAM_INT); 
			$stmt->bindParam(':page', $page, PDO::PARAM_STR); 
			$stmt->bindParam(':citation', $citation, PDO::PARAM_STR); 
			$stmt->bindParam(':textdraduction', $textdraduction, PDO::PARAM_STR); 
			$stmt->bindParam(':notesearch', $notesearch, PDO::PARAM_STR); 
			$stmt->bindParam(':datecreated', $datecreated, PDO::PARAM_STR); 
 

            $stmt->execute();     
            $this->lastInsertId = $this->db->lastInsertId(); 
            
            if ($stmt->rowCount() == 0) {
				$this->lasterror = 'Erreur Sql insert'.'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>description</b> = [$description],<b>private</b> = [$private],<b>category</b> = [$category],<b>icon</b> = [$icon],<b>sourcetext</b> = [$sourcetext],<b>sourceurl</b> = [$sourceurl],<b>quality</b> = [$quality],<b>page</b> = [$page],<b>citation</b> = [$citation],<b>textdraduction</b> = [$textdraduction],<b>notesearch</b> = [$notesearch],<b>datecreated</b> = [$datecreated]";
				return false;
			}              
                   
            return true;

        } catch (Exception $e) {
             $this->lasterror = $e->getMessage().'  (<b>Id</b> = '.$id.'). <b>Sqlst</b> = ['.$sqlSt.'] values : '."<b>name</b> = [$name],<b>description</b> = [$description],<b>private</b> = [$private],<b>category</b> = [$category],<b>icon</b> = [$icon],<b>sourcetext</b> = [$sourcetext],<b>sourceurl</b> = [$sourceurl],<b>quality</b> = [$quality],<b>page</b> = [$page],<b>citation</b> = [$citation],<b>textdraduction</b> = [$textdraduction],<b>notesearch</b> = [$notesearch],<b>datecreated</b> = [$datecreated]";
            return false;
        }
    }

    /*
        Delete one reccord from source.
        
        parameters : $id (reccord id).
        return : True if no error.
    */
    function delete($id) {

        $this->lasterror="";

        $sqlSt="
		delete from source             
		where id = :id; 
            ";   
     
        try {        

            $stmt = $this->db->prepare($sqlSt);  
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();        
            
			if ($stmt->rowCount() == 0) {
				$this->lasterror = "Erreur Sql delete ".' (<b>Id</b> ='.$id.')';       
				return false;
			}              

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage().' (<b>Id</b>='.$id.')';
            return false;
        }
        return true;
    }

    /*
        Get id min, id max, record count from source  
        
        parameters : None
        return : count value or False in case of error
    */
	function getCount() {
		
        $this->lasterror="";

        $sqlSt="
		select min(id) as minid, max(id) as maxid, count(*) as count 
		from source 
                ";

        try {        

            $stmt = $this->db->prepare($sqlSt);        
            $stmt->execute(); 
            $results = $stmt->fetchAll(PDO::FETCH_ASSOC); 
            return $results[0];          

        } catch (Exception $e) {
            $this->lasterror = $e->getMessage();
            return array( 'minid' => -1, 'maxid' => -1, 'count' => -1);
        }
        		
		//return $this->count;
		return $results[0];
	}




	public $colmeta = [
	'a.id' => array (
		'metades' => "id",
		'sortformat' => "{{sortformat}}",
		'listlen' => 4,
		'listlib' => 'a_id',
		'listlink' => 'on',
		'selectlen' => 4,
		'selectlib' => 'a_id',
		'selectlink' => 'on',
		'selectdisplay' => '',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => '', 
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 

		),
	'a.name' => array ( 
		'metades' => "Nom de la source",
		'sortformat' => "", 
		'listlen' => 30,
		'listlib' => 'Nom' , 
		'listlink' => '',
		'selectlen' => 12,
		'selectlib' => 'Nom' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.description' => array ( 
		'metades' => "description",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'a_description' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'a_description' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.private' => array ( 
		'metades' => "private",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'a_private' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'a_private' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.category' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'category' , 
		'listlink' => '',
		'selectlen' => 12,
		'selectlib' => 'category' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.icon' => array ( 
		'metades' => "icon",
		'sortformat' => "", 
		'listlen' => 4,
		'listlib' => 'icon' , 
		'listlink' => '',
		'selectlen' => 4,
		'selectlib' => 'icon' , 
		'selectlink' => '',
		'selectdisplay' => 'urlpic',
		'selectdisplaywidth' => '50', 
		'selectdisplayheight' => '50', 
		'listdisplay' => 'urlpic',
		'listdisplaywidth' => '50', 
		'listdisplayheight' => '50' 
),
	'a.sourcetext' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'sourcetext' , 
		'listlink' => '',
		'selectlen' => 12,
		'selectlib' => 'sourcetext' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.sourceurl' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'sourceurl' , 
		'listlink' => '',
		'selectlen' => 12,
		'selectlib' => 'sourceurl' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.quality' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 8,
		'listlib' => 'quality' , 
		'listlink' => '',
		'selectlen' => 8,
		'selectlib' => 'quality' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.page' => array ( 
		'metades' => "Page dans le document",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'Page' , 
		'listlink' => '',
		'selectlen' => 12,
		'selectlib' => 'Page' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.citation' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'citation' , 
		'listlink' => '',
		'selectlen' => 12,
		'selectlib' => 'citation' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.textdraduction' => array ( 
		'metades' => "",
		'sortformat' => "", 
		'listlen' => 12,
		'listlib' => 'textdraduction' , 
		'listlink' => '',
		'selectlen' => 12,
		'selectlib' => 'textdraduction' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.notesearch' => array ( 
		'metades' => "Notes de recherche",
		'sortformat' => "", 
		'listlen' => 0,
		'listlib' => 'Notes de recherche' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'Notes de recherche' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
),
	'a.datecreated' => array ( 
		'metades' => "datecreated",
		'sortformat' => "date", 
		'listlen' => 0,
		'listlib' => 'a_datecreated' , 
		'listlink' => '',
		'selectlen' => 0,
		'selectlib' => 'a_datecreated' , 
		'selectlink' => '',
		'selectdisplay' => 'text',
		'selectdisplaywidth' => '0', 
		'selectdisplayheight' => '0', 
		'listdisplay' => 'text',
		'listdisplaywidth' => '0', 
		'listdisplayheight' => '0' 
)

			
	];

    /*
        Get field property value
        
        Parameters : field name and property name.
        return : value of property.
    */

	function getMeta( $fieldkey , $metakey ) {
		return $this->colmeta [$fieldkey][$metakey];
	}

    /*
        Get labels for list table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderList() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['listlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['listlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenList( $field ) {		
		
		return $this->colmeta[$field]['listlen'];
	}

	function getTableFieldLinkList( $field ) {		
		
		return $this->colmeta[$field]['listlink'];
	}

    /*
        Get labels for select table header.
        
        Parameters : None.
        return : String.
    */

	function getTableHeaderSelect() {		
		
		$labelsStr ='';
		
		foreach (  $this->colmeta as $k => $v) {
			if ( $v['selectlen'] > 0 ) 
				$labelsStr = $labelsStr.'<th title="'.$v['metades'].'" >'.$v['selectlib'] .'</th>'."\n";
		}				
		return $labelsStr;
	}
	
	function getTableFieldLenSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlen'];
	}

	function getTableFieldLinkSelect( $field ) {		
		
		return $this->colmeta[$field]['selectlink'];
	}

	
    /*
        Check user input values for source.
        
        Parameters : array of fields with regexp  paterns. ex: array( $nom =>'^(?!\s*$).+' , $icone => '')
        return : False if at last one regexp does not match.
    */
    function checkValue( $arrayCheck ) {

        $indexfield=1;
        foreach ( $arrayCheck as $value => $pattern) {

            if ($pattern=='') continue;

            $pattern='/'.$pattern.'/';

            if (!preg_match($pattern, $value)) {
                $this->lasterror = "Erreur champ #".$indexfield. '. Valeur:['.$value.']';
                return false;                
            }

            $indexfield+=1;

        }

        return true;
    }

} // end class

?>
